@@ -332,11 +332,20 @@ class Node(object):
         return children_list
 
 
-    roleName = property(Accessibility.Accessible.getRoleName)
+    @property
+    def roleName(self):
+        """
+        Return the role name of the node, with optional button compatibility.
+        """
+        role_name = Accessibility.Accessible.getRoleName(self)
+        if config.buttonRoleCompat and role_name == "button":
+            return "push button"
+        return role_name
     role = property(Accessibility.Accessible.getRole)
     name = property(Accessibility.Accessible.name)
     parent = property(Accessibility.Accessible.parent)
     indexInParent = property(Accessibility.Accessible.getIndexInParent)
+    attributesList = property(Accessibility.Accessible.getAttributes)
     __window_id = None
 
 
@@ -635,6 +644,16 @@ class Node(object):
         except NotImplementedError:
             return None
 
+    @property
+    def center(self):
+        """
+        A tuple containing the center position of the Accessible:(x, y)
+        """
+
+        debug_log("center(self)")
+
+        x, y, w, h = self.extents
+        return x + w / 2, y + h / 2
 
     def contains(self, x, y):
         """
@@ -1226,6 +1245,8 @@ class Node(object):
             return (ancestor, predicate.IsAMenuItemNamed(self.name), isRecursive)
         elif self.roleName == "text":
             return (ancestor, predicate.IsATextEntryNamed(self.name), isRecursive)
+        elif self.roleName == "button":
+            return (ancestor, predicate.IsAButtonNamed(self.name), isRecursive)
         elif self.roleName == "push button":
             return (ancestor, predicate.IsAButtonNamed(self.name), isRecursive)
         elif self.roleName == "frame":
@@ -1429,8 +1450,8 @@ class Node(object):
 
         return None
 
-
-    def child(self, name="", roleName="", description="", label="", recursive=True, retry=True, debugName=None, showingOnly=None):
+    # Various wrapper/helper search methods:
+    def child(self, name="", roleName="", description="", label="", identifier="", recursive=True, retry=True, debugName=None, showingOnly=None):
         """
         Finds a child satisying the given criteria.
 
@@ -1439,14 +1460,13 @@ class Node(object):
         also logs the search.
         """
 
-        debug_log("child(self, name=%s, roleName=%s, description=%s, label=%s, recursive=%s, retry=%s, debugName=%s, showingOnly=%s)" %
-                      (str(name), str(roleName), str(description), str(label), str(recursive), str(retry), str(debugName), str(showingOnly)))
+        debug_log("child(self, name=%s, roleName=%s, description=%s, label=%s, identifier=%s, recursive=%s, retry=%s, debugName=%s, showingOnly=%s)" %
+            (str(name), str(roleName), str(description), str(label), str(identifier), str(recursive), str(retry), str(debugName), str(showingOnly)))
 
-        return self.findChild(predicate.GenericPredicate(name=name, roleName=roleName, description=description, label=label),
-                              recursive=recursive, retry=retry, debugName=debugName, showingOnly=showingOnly)
+        return self.findChild(predicate.GenericPredicate(name=name, roleName=roleName, description=description,
+                              label=label, identifier=identifier), recursive=recursive, retry=retry, debugName=debugName, showingOnly=showingOnly)
 
-
-    def isChild(self, name="", roleName="", description="", label="", recursive=True, retry=False, debugName=None, showingOnly=None):
+    def isChild(self, name="", roleName="", description="", label="", identifier="", recursive=True, retry=False, debugName=None, showingOnly=None):
         """
         Determines whether a child satisying the given criteria exists.
 
@@ -1457,12 +1477,14 @@ class Node(object):
         any other exceptions. It also logs the search.
         """
 
-        debug_log("isChild(self, name=%s, roleName=%s, description=%s, label=%s, recursive=%s, retry=%s, debugName=%s, showingOnly=%s)" %
-                      (str(name), str(roleName), str(description), str(label), str(recursive), str(retry), str(debugName), str(showingOnly)))
+        debug_log("isChild(self, name=%s, roleName=%s, description=%s, label=%s, identifier=%s, recursive=%s, retry=%s, debugName=%s, showingOnly=%s)" %
+            (str(name), str(roleName), str(description), str(label), str(identifier), str(recursive), str(retry), str(debugName), str(showingOnly)))
 
         try:
-            self.findChild(predicate.GenericPredicate(name=name, roleName=roleName, description=description, label=label),
-                           recursive=recursive, retry=retry, debugName=debugName, showingOnly=showingOnly)
+            self.findChild(
+                predicate.GenericPredicate(
+                    name=name, roleName=roleName, description=description, label=label, identifier=identifier),
+                recursive=recursive, retry=retry, debugName=debugName, showingOnly=showingOnly)
             return True
         except SearchError:
             return False
