@@ -100,7 +100,7 @@ def run(string, timeout=config.runTimeout, interval=config.runInterval, desktop=
     starting, or until timeout is reached. If dumb is True, returns when timeout is reached.
     """
 
-    debug_log("run(string=%s, timeout=%s, interval=%s, desktop=%s, dumb=%s, appName=%s)" % 
+    debug_log("run(string=%s, timeout=%s, interval=%s, desktop=%s, dumb=%s, appName=%s)" %
                   (str(string), str(timeout), str(interval), str(desktop), str(dumb), str(appName)))
 
     if not desktop:
@@ -330,7 +330,7 @@ class Lock(object):
 
     def __getPostfix(self):
         """
-        Generate a length of 5 random string that serves as file name suffix. 
+        Generate a length of 5 random string that serves as file name suffix.
         """
 
         import random
@@ -501,10 +501,14 @@ def get_current_x_window_position():
     except ModuleNotFoundError as e:
         raise ImportError("python-xlib is required for this script to run. Please install it i.e. using 'pip install python-xlib'.") from e
 
-    
+
     d = display.Display()
     root = d.screen().root
-    window_id = root.get_full_property(d.intern_atom('_NET_ACTIVE_WINDOW'), X.AnyPropertyType).value[0]
+    prop = root.get_full_property(d.intern_atom('_NET_ACTIVE_WINDOW'), X.AnyPropertyType)
+    if prop is None:
+        return 0, 0
+
+    window_id = prop.value[0]
     window = d.create_resource_object('window', window_id)
 
     try:
@@ -589,7 +593,7 @@ class GnomeShell:  # pragma: no cover
 
     def getApplicationMenuItem(self, item, search_by_item="Quit"):
         """
-        Returns a particilar menu item node. Uses a different 'Quit' or custom item name for 
+        Returns a particilar menu item node. Uses a different 'Quit' or custom item name for
         reference, but also attempts to use the given item if the general reference fails.
         """
 
